@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 
 
 class netbios(Unit):
@@ -11,7 +11,7 @@ class netbios(Unit):
     letter A.
     """
 
-    def __init__(self, key: arg(help="Provide a single letter to use as the offset.") = B'A'):
+    def __init__(self, key: Arg(help="Provide a single letter to use as the offset.") = B'A'):
         if len(key) != 1:
             raise ValueError("The key must be a binary string of length exactly 1")
         super().__init__(key=key[0])
