@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import json
+import re
 
 from email.parser import BytesParser
 from functools import partial
@@ -81,6 +82,9 @@ class xtmail(PathExtractorUnit):
             yield UnpackResult(F'attachments/{path}', attachment.data)
 
     def _get_parts_regular(self, data):
+        if not re.match(BR'^[\s!-~]+$', data):
+            raise ValueError('This is not a plaintext email message.')
+
         msg = BytesParser().parsebytes(data)
 
         yield from self._get_headparts(msg.items())
@@ -123,3 +127,9 @@ class xtmail(PathExtractorUnit):
         except Exception:
             self.log_debug('failed parsing input as Outlook message')
             yield from self._get_parts_regular(data)
+
+    @classmethod
+    def handles(cls, data: bytearray) -> bool:
+        if data.startswith(B'\xD0\xCF\x11\xE0\xA1\xB1\x1A\xE1'):
+            return True
+        return b'\nReceived: from' in data
