@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from __future__ import annotations
+from typing import Union
+
 import json
 
 from refinery.units.formats import PathExtractorUnit, UnpackResult, Unit
@@ -10,8 +13,8 @@ class xtjson(PathExtractorUnit):
     """
     Extract values from a JSON document.
     """
-    _STRICT_PATH_MATCHING = True
-    _CUSTOM_PATH_SEPARATE = '.'
+    _strict_path_matching = True
+    _custom_path_separator = '.'
 
     def unpack(self, data):
 
@@ -47,7 +50,7 @@ class xj0(Unit):
     """
     def __init__(
         self,
-        key: Unit.Arg(help='The key of the value to be extracted as the main body of the chunk.'),
+        key: Unit.Arg.Binary(help='Optional key of a value to become the main body of the chunk.') = None,
         raw: Unit.Arg('-r', group='META', help='Do not extract any other fields as metadata.') = False,
         all: Unit.Arg('-a', group='META', help='Extract all other fields as metadata.') = False
     ):
@@ -74,10 +77,30 @@ class xj0(Unit):
         doc: dict = json.loads(data)
         if not isinstance(doc, dict):
             raise ValueError('The input must be a JSON dictionary.')
-        result = doc.pop(self.args.key.decode(self.codec), '').encode(self.codec)
+        key = self.args.key
+        result = key and doc.pop(key.decode(self.codec), '').encode(self.codec)
         if self.args.raw:
             return result
         else:
             return self.labelled(result, **{
                 key: value for key, value in doc.items() if acceptable(key, value)
             })
+
+
+class xjl(Unit):
+    """
+    Returns all JSON elements from a JSON iterable as individual outputs.
+    """
+
+    def process(self, data):
+        try:
+            doc: Union[list, dict] = json.loads(data)
+        except Exception:
+            from refinery.units.pattern.carve_json import carve_json
+            doc = data | carve_json | json.loads
+        try:
+            it = doc.values()
+        except AttributeError:
+            it = doc
+        for item in it:
+            yield json.dumps(item).encode(self.codec)
