@@ -3,7 +3,7 @@
 from collections import defaultdict
 from typing import Generator, Iterable
 
-from refinery.units import arg, Unit, Chunk
+from refinery.units import Arg, Unit, Chunk
 from refinery.lib.meta import check_variable_name
 
 
@@ -13,7 +13,7 @@ class groupby(Unit):
     blocks and cannot stream any output until the input frame is consumed: It has
     to read every input chunk to make sure that all groupings are complete.
     """
-    def __init__(self, name: arg(type=str, help='name of the meta variable')):
+    def __init__(self, name: Arg(type=str, help='name of the meta variable')):
         super().__init__(name=check_variable_name(name))
 
     def process(self, data):
